@@ -33,6 +33,7 @@ from .formatters.admin import (
     ClustersFormatter,
     ClusterUserFormatter,
     OrgClusterFormatter,
+    OrgClustersFormatter,
     OrgsFormatter,
     OrgUserFormatter,
 )
@@ -110,6 +111,14 @@ async def get_admin_clusters(root: Root) -> None:
     show_default=True,
     help="Default maximum running jobs quota (`unlimited' stands for no limit)",
 )
+@option(
+    "--default-role",
+    default=_ClusterUserRoleType.USER.value,
+    metavar="[ROLE]",
+    type=click.Choice([str(role) for role in list(_ClusterUserRoleType)]),
+    show_default=True,
+    help="Default role for new users added to cluster",
+)
 @argument("cluster_name", required=True, type=str)
 @argument("config", required=True, type=click.File(encoding="utf8", lazy=False))
 async def add_cluster(
@@ -118,6 +127,7 @@ async def add_cluster(
     config: IO[str],
     default_credits: str,
     default_jobs: str,
+    default_role: str,
     skip_provisioning: bool = False,
 ) -> None:
     """
@@ -131,6 +141,7 @@ async def add_cluster(
         cluster_name,
         default_credits=_parse_credits_value(default_credits),
         default_quota=_Quota(_parse_jobs_value(default_jobs)),
+        default_role=_ClusterUserRoleType(default_role),
     )
     if skip_provisioning:
         return
@@ -159,12 +170,21 @@ async def add_cluster(
     show_default=True,
     help="Default maximum running jobs quota (`unlimited' stands for no limit)",
 )
+@option(
+    "--default-role",
+    default=_ClusterUserRoleType.USER.value,
+    metavar="[ROLE]",
+    type=click.Choice([str(role) for role in list(_ClusterUserRoleType)]),
+    show_default=True,
+    help="Default role for new users added to cluster",
+)
 @argument("cluster_name", required=True, type=str)
 async def update_cluster(
     root: Root,
     cluster_name: str,
     default_credits: str,
     default_jobs: str,
+    default_role: str,
 ) -> None:
     """
     Update a cluster.
@@ -174,6 +194,7 @@ async def update_cluster(
             name=cluster_name,
             default_credits=_parse_credits_value(default_credits),
             default_quota=_Quota(_parse_jobs_value(default_jobs)),
+            default_role=_ClusterUserRoleType(default_role),
         )
     )
     if not root.quiet:
@@ -532,7 +553,7 @@ async def get_cluster_users(
 @argument(
     "role",
     required=False,
-    default=_ClusterUserRoleType.USER.value,
+    default=None,
     metavar="[ROLE]",
     type=click.Choice([str(role) for role in list(_ClusterUserRoleType)]),
 )
@@ -565,7 +586,7 @@ async def add_cluster_user(
     root: Root,
     cluster_name: str,
     user_name: str,
-    role: str,
+    role: Optional[str],
     credits: Optional[str],
     jobs: Optional[str],
     org: Optional[str],
@@ -575,12 +596,13 @@ async def add_cluster_user(
 
     The command supports one of 3 user roles: admin, manager or user.
     """
-    # Use cluster defaults credits/quota for "user" role. Unlimited for other roles.
-    if role == "user" and credits is None:
+    # Use cluster defaults credits/quota for "user-like" roles.
+    # Unlimited for other roles.
+    if credits is None and role in (None, "user", "member"):
         balance = None
     else:
         balance = _Balance(credits=_parse_credits_value(credits or UNLIMITED))
-    if role == "user" and jobs is None:
+    if jobs is None and role in (None, "user", "member"):
         quota = None
     else:
         quota = _Quota(total_running_jobs=_parse_jobs_value(jobs or UNLIMITED))
@@ -1222,7 +1244,7 @@ async def get_org_clusters(root: Root, cluster_name: str) -> None:
     """
     Print the list of all orgs in the cluster
     """
-    fmt = OrgClusterFormatter()
+    fmt = OrgClustersFormatter()
     with root.status(f"Fetching the list of orgs of cluster [b]{cluster_name}[/b]"):
         org_clusters = await root.client._admin.list_org_clusters(
             cluster_name=cluster_name
@@ -1268,6 +1290,14 @@ async def get_org_clusters(root: Root, cluster_name: str) -> None:
     show_default=True,
     help="Default maximum running jobs quota (`unlimited' stands for no limit)",
 )
+@option(
+    "--default-role",
+    default=_ClusterUserRoleType.USER.value,
+    metavar="[ROLE]",
+    type=click.Choice([str(role) for role in list(_ClusterUserRoleType)]),
+    show_default=True,
+    help="Default role for new users added to org cluster",
+)
 @option(
     "--storage-size",
     metavar="AMOUNT",
@@ -1282,27 +1312,31 @@ async def add_org_cluster(
     jobs: str,
     default_credits: str,
     default_jobs: str,
+    default_role: str,
     storage_size: Optional[int],
 ) -> None:
     """
     Add org access to specified cluster.
 
     """
-    await root.client._admin.create_org_cluster(
+    org_cluster = await root.client._admin.create_org_cluster(
         cluster_name=cluster_name,
         org_name=org_name,
         balance=_Balance(credits=_parse_credits_value(credits)),
         quota=_Quota(total_running_jobs=_parse_jobs_value(jobs)),
         default_credits=_parse_credits_value(default_credits),
         default_quota=_Quota(_parse_jobs_value(default_jobs)),
+        default_role=_ClusterUserRoleType(default_role),
         storage_size_mb=storage_size,
     )
     if not root.quiet:
         root.print(
             f"Added org [bold]{rich_escape(org_name)}[/bold] to "
-            f"[bold]{rich_escape(cluster_name)}[/bold]",
+            f"[bold]{rich_escape(cluster_name)}[/bold]. Info:",
             markup=True,
         )
+        fmt = OrgClusterFormatter()
+        root.print(fmt(org_cluster, skip_cluster_org=True))
 
 
 @command()
@@ -1342,6 +1376,14 @@ async def add_org_cluster(
     show_default=True,
     help="Default maximum running jobs quota (`unlimited' stands for no limit)",
 )
+@option(
+    "--default-role",
+    default=_ClusterUserRoleType.USER.value,
+    metavar="[ROLE]",
+    type=click.Choice([str(role) for role in list(_ClusterUserRoleType)]),
+    show_default=True,
+    help="Default role for new users added to org cluster",
+)
 async def update_org_cluster(
     root: Root,
     cluster_name: str,
@@ -1350,30 +1392,34 @@ async def update_org_cluster(
     jobs: str,
     default_credits: str,
     default_jobs: str,
+    default_role: str,
 ) -> None:
     """
     Update org cluster quotas.
 
     """
-    await root.client._admin.update_org_cluster(
-        _OrgCluster(
-            cluster_name=cluster_name,
-            org_name=org_name,
-            balance=_Balance(credits=_parse_credits_value(credits)),
-            quota=_Quota(total_running_jobs=_parse_jobs_value(jobs)),
-            default_credits=_parse_credits_value(default_credits),
-            default_quota=_Quota(_parse_jobs_value(default_jobs)),
-        )
+    org_cluster = _OrgCluster(
+        cluster_name=cluster_name,
+        org_name=org_name,
+        balance=_Balance(credits=_parse_credits_value(credits)),
+        quota=_Quota(total_running_jobs=_parse_jobs_value(jobs)),
+        default_credits=_parse_credits_value(default_credits),
+        default_quota=_Quota(_parse_jobs_value(default_jobs)),
+        default_role=_ClusterUserRoleType(default_role),
     )
+    await root.client._admin.update_org_cluster(org_cluster)
     if not root.quiet:
         root.print(
-            f"Added org [bold]{rich_escape(org_name)}[/bold] to "
-            f"[bold]{rich_escape(cluster_name)}[/bold]",
+            f"Org [bold]{rich_escape(org_name)}[/bold] info in cluster"
+            f" [bold]{rich_escape(cluster_name)}[/bold] successfully updated. "
+            f"New info:",
             markup=True,
         )
+        fmt = OrgClusterFormatter()
+        root.print(fmt(org_cluster, skip_cluster_org=True))
 
 
-@command(hidden=True)
+@command()
 @option("--force", default=False, help="Skip prompt", is_flag=True)
 @argument("cluster_name", required=True, type=str)
 @argument("org_name", required=True, type=str)
@@ -1397,6 +1443,62 @@ async def remove_org_cluster(
     await root.client._admin.delete_org_cluster(cluster_name, org_name)
 
 
+@command()
+@argument("cluster_name", required=True, type=str)
+@argument("org_name", required=True, type=str)
+@option(
+    "--default-credits",
+    metavar="AMOUNT",
+    type=str,
+    default=UNLIMITED,
+    show_default=True,
+    help="Default credits amount to set (`unlimited' stands for no limit)",
+)
+@option(
+    "--default-jobs",
+    metavar="AMOUNT",
+    type=str,
+    default=UNLIMITED,
+    show_default=True,
+    help="Default maximum running jobs quota (`unlimited' stands for no limit)",
+)
+@option(
+    "--default-role",
+    default=_ClusterUserRoleType.USER.value,
+    metavar="[ROLE]",
+    type=click.Choice([str(role) for role in list(_ClusterUserRoleType)]),
+    show_default=True,
+    help="Default role for new users added to org cluster",
+)
+async def set_org_cluster_defaults(
+    root: Root,
+    cluster_name: str,
+    org_name: str,
+    default_credits: str,
+    default_jobs: str,
+    default_role: str,
+) -> None:
+    """
+    Set org cluster defaults to given value
+    """
+    org_cluster = await root.client._admin.update_org_cluster_defaults(
+        cluster_name=cluster_name,
+        org_name=org_name,
+        default_credits=_parse_credits_value(default_credits),
+        default_quota=_Quota(_parse_jobs_value(default_jobs)),
+        default_role=_ClusterUserRoleType(default_role),
+    )
+    if not root.quiet:
+        root.print(
+            f"Org [bold]{rich_escape(org_name)}[/bold] info in cluster"
+            f" [bold]{rich_escape(cluster_name)}[/bold] successfully updated. "
+            f"New info:",
+            markup=True,
+        )
+        fmt = OrgClusterFormatter()
+        root.print(fmt(org_cluster, skip_cluster_org=True))
+
+
 @command()
 @argument("cluster_name", required=True, type=str)
 @argument("org_name", required=True, type=str)
@@ -1561,6 +1663,7 @@ admin.add_command(add_org_cluster)
 admin.add_command(update_org_cluster)
 admin.add_command(remove_org_cluster)
 
+admin.add_command(set_org_cluster_defaults)
 admin.add_command(get_org_cluster_quota)
 admin.add_command(set_org_cluster_quota)
 admin.add_command(set_org_cluster_credits)
