@@ -34,12 +34,18 @@ async def show(root: Root) -> None:
     """
     Print current settings.
     """
+
+    with root.status("Fetching the current config"):
+        await root.client.config.fetch()
     cluster_name = root.client.config.cluster_name
     fmt = ConfigFormatter()
-    try:
-        jobs_capacity = await root.client.jobs.get_capacity(cluster_name=cluster_name)
-    except (ClientConnectionError, AuthorizationError):
-        jobs_capacity = {}
+    with root.status("Fetching the jobs capacity"):
+        try:
+            jobs_capacity = await root.client.jobs.get_capacity(
+                cluster_name=cluster_name
+            )
+        except (ClientConnectionError, AuthorizationError):
+            jobs_capacity = {}
     quota = await root.client.users.get_quota()
     org_quota = await root.client.users.get_org_quota()
     root.print(fmt(root.client.config, jobs_capacity, quota, org_quota))
@@ -54,12 +60,17 @@ async def show_token(root: Root) -> None:
 
 
 def _print_welcome(root: Root, url: URL) -> None:
-    root.print(
-        f"Logged into {url} as [u]{root.client.config.username}[/u]"
-        f", current cluster is [b]{root.client.config.cluster_name}[/b], "
-        f"org is [b]{root.client.config.org_name or ORG.NO_ORG_STR}[/b]",
-        markup=True,
-    )
+    if root.client.config.clusters:
+        root.print(
+            f"Logged into {url} as [u]{root.client.config.username}[/u]"
+            f", current cluster is [b]{root.client.config.cluster_name}[/b], "
+            f"org is [b]{root.client.config.org_name or ORG.NO_ORG_STR}[/b]",
+            markup=True,
+        )
+    else:
+        root.print(
+            f"Logged into {url} as [u]{root.client.config.username}[/u]", markup=True
+        )
     root.print(
         "Read the docs at https://docs.neu.ro or run `neuro --help` "
         "to see the reference"
