@@ -1,5 +1,7 @@
 import pathlib
+from typing import Optional
 
+from neuro_cli.click_types import CLUSTER, ORG
 from neuro_cli.formatters.secrets import (
     BaseSecretsFormatter,
     SecretsFormatter,
@@ -19,8 +21,13 @@ def secret() -> None:
 
 
 @command()
+@option(
+    "--cluster",
+    type=CLUSTER,
+    help="Look on a specified cluster (the current cluster by default).",
+)
 @option("--full-uri", is_flag=True, help="Output full disk URI.")
-async def ls(root: Root, full_uri: bool) -> None:
+async def ls(root: Root, full_uri: bool, cluster: Optional[str]) -> None:
     """
     List secrets.
     """
@@ -31,7 +38,9 @@ async def ls(root: Root, full_uri: bool) -> None:
             uri_fmtr: URIFormatter = str
         else:
             uri_fmtr = uri_formatter(
-                username=root.client.username, cluster_name=root.client.cluster_name
+                username=root.client.username,
+                cluster_name=cluster or root.client.cluster_name,
+                org_name=root.client.config.org_name,
             )
         secrets_fmtr = SecretsFormatter(
             uri_fmtr,
@@ -39,18 +48,31 @@ async def ls(root: Root, full_uri: bool) -> None:
 
     secrets = []
     with root.status("Fetching secrets") as status:
-        async for secret in root.client.secrets.list():
-            secrets.append(secret)
-            status.update(f"Fetching secrets ({len(secrets)} loaded)")
+        async with root.client.secrets.list(cluster_name=cluster) as it:
+            async for secret in it:
+                secrets.append(secret)
+                status.update(f"Fetching secrets ({len(secrets)} loaded)")
 
     with root.pager():
         root.print(secrets_fmtr(secrets))
 
 
 @command()
+@option(
+    "--cluster",
+    type=CLUSTER,
+    help="Perform on a specified cluster (the current cluster by default).",
+)
+@option(
+    "--org",
+    type=ORG,
+    help="Look on a specified org (the current org by default).",
+)
 @argument("key")
 @argument("value")
-async def add(root: Root, key: str, value: str) -> None:
+async def add(
+    root: Root, key: str, value: str, cluster: Optional[str], org: Optional[str]
+) -> None:
     """
     Add secret KEY with data VALUE.
 
@@ -61,17 +83,29 @@ async def add(root: Root, key: str, value: str) -> None:
       neuro secret add KEY_NAME VALUE
       neuro secret add KEY_NAME @path/to/file.txt
     """
-    await root.client.secrets.add(key, read_data(value))
+    await root.client.secrets.add(
+        key, read_data(value), cluster_name=cluster, org_name=org
+    )
 
 
 @command()
+@option(
+    "--cluster",
+    type=CLUSTER,
+    help="Perform on a specified cluster (the current cluster by default).",
+)
+@option(
+    "--org",
+    type=ORG,
+    help="Look on a specified org (the current org by default).",
+)
 @argument("key")
-async def rm(root: Root, key: str) -> None:
+async def rm(root: Root, key: str, cluster: Optional[str], org: Optional[str]) -> None:
     """
     Remove secret KEY.
     """
 
-    await root.client.secrets.rm(key)
+    await root.client.secrets.rm(key, cluster_name=cluster, org_name=org)
     if root.verbosity > 0:
         root.print(f"Secret with key '{key}' was successfully removed")
 
