@@ -222,11 +222,18 @@ async def glob(root: Root, patterns: Sequence[URL]) -> None:
 
 
 @command()
-async def df(root: Root) -> None:
+@argument(
+    "path",
+    required=False,
+    type=PlatformURIType(allowed_schemes=["storage"], complete_file=False),
+)
+async def df(root: Root, path: Optional[URL]) -> None:
     """
-    Show current usage of storage.
+    Show current storage usage.
+
+    If PATH is specified, show storage usage of which path is a part.
     """
-    usage = await root.client.storage.disk_usage()
+    usage = await root.client.storage.disk_usage(uri=path)
     root.print(DiskUsageFormatter()(usage))
 
 
@@ -238,13 +245,17 @@ class FileFilterParserOption(click.parser.Option):
 
 
 class FileFilterOption(Option):
+    def __init__(self, *args: Any, is_exclude: bool, **kwargs: Any) -> None:
+        super().__init__(*args, **kwargs)
+        self._is_exclude = is_exclude
+
     def add_to_parser(self, parser: click.parser.OptionParser, ctx: Any) -> None:
         option = FileFilterParserOption(
             opts=self.opts,
             dest=self.name,
             action="append",
             nargs=self.nargs,
-            const=self.flag_value,
+            const=self._is_exclude,
             obj=self,
         )
         parser._opt_prefixes.update(option.prefixes)
@@ -254,12 +265,15 @@ class FileFilterOption(Option):
             parser._long_opt[opt] = option
 
 
-def filter_option(*args: str, flag_value: bool, help: str) -> Callable[[Any], Any]:
+def filter_option(
+    optname: str, varname: str, is_exclude: bool, help: str
+) -> Callable[[Any], Any]:
     return option(
-        *args,
+        optname,
+        varname,
         multiple=True,
         cls=FileFilterOption,
-        flag_value=flag_value,
+        is_exclude=is_exclude,
         type=click.UNPROCESSED,
         help=help,
         secure=True,
@@ -316,13 +330,13 @@ def filter_option(*args: str, flag_value: bool, help: str) -> Callable[[Any], An
 @filter_option(
     "--exclude",
     "filters",
-    flag_value=True,
+    is_exclude=True,
     help=("Exclude files and directories that match the specified pattern."),
 )
 @filter_option(
     "--include",
     "filters",
-    flag_value=False,
+    is_exclude=False,
     help=("Don't exclude files and directories that match the specified pattern."),
 )
 @option(
@@ -689,7 +703,8 @@ async def mv(
 async def tree(
     root: Root, path: URL, size: bool, human_readable: bool, sort: str, show_all: bool
 ) -> None:
-    """List storage in a tree-like format
+    """
+    List storage in a tree-like format
 
     Tree is a recursive directory listing program that produces a depth indented listing
     of files, which is colorized ala dircolors if the LS_COLORS environment variable is
