@@ -11,6 +11,11 @@ from neuro_sdk import Client, Cluster, Preset
 
 from neuro_cli.config import prompt_cluster
 from neuro_cli.root import Root
+from neuro_cli.utils import Command, Context
+
+
+async def cmd() -> None:
+    pass
 
 
 @pytest.mark.skipif(
@@ -33,6 +38,7 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
                 )
             },
             name="first",
+            orgs=[None],
         ),
         "second": Cluster(
             registry_url=URL("https://registry2-dev.neu.ro"),
@@ -48,6 +54,7 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
                 )
             },
             name="second",
+            orgs=[None],
         ),
     }
 
@@ -66,6 +73,7 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
         skip_gmp_stats=True,
         show_traceback=False,
         iso_datetime_format=False,
+        ctx=Context(Command(cmd, name="")),
     )
 
     async def _async_make_client() -> Client:
@@ -75,6 +83,7 @@ def test_prompt_cluster(make_client: Callable[..., Client]) -> None:
 
     session = mock.Mock()
     loop = root._runner._loop
+    assert loop is not None
     fut = loop.create_future()
     fut.set_result("second")
     session.prompt_async.return_value = fut
@@ -103,6 +112,7 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
                 )
             },
             name="first",
+            orgs=[None],
         ),
         "second": Cluster(
             registry_url=URL("https://registry2-dev.neu.ro"),
@@ -118,6 +128,7 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
                 )
             },
             name="second",
+            orgs=[None],
         ),
     }
 
@@ -136,6 +147,7 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
         skip_gmp_stats=True,
         show_traceback=False,
         iso_datetime_format=False,
+        ctx=Context(Command(cmd, name="")),
     )
 
     async def _async_make_client() -> Client:
@@ -145,6 +157,7 @@ def test_prompt_cluster_default(make_client: Callable[..., Client]) -> None:
 
     session = mock.Mock()
     loop = root._runner._loop
+    assert loop is not None
     fut = loop.create_future()
     fut.set_result("")
     session.prompt_async.return_value = fut
